Tutorial 1: Your First Curve Fit
=================================

.. deprecated::
   This tutorial has been superseded by the structured tutorial guide.

See :doc:`/tutorials/routine/getting_started/first_fit` for the updated version.
